Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type TFJobLister ¶
type TFJobLister interface {
// List lists all TFJobs in the indexer.
List(selector labels.Selector) (ret []*v1.TFJob, err error)
// TFJobs returns an object that can list and get TFJobs.
TFJobs(namespace string) TFJobNamespaceLister
TFJobListerExpansion
}
TFJobLister helps list TFJobs.
func NewTFJobLister ¶
func NewTFJobLister(indexer cache.Indexer) TFJobLister
NewTFJobLister returns a new TFJobLister.
type TFJobListerExpansion ¶
type TFJobListerExpansion interface{}
TFJobListerExpansion allows custom methods to be added to TFJobLister.
type TFJobNamespaceLister ¶
type TFJobNamespaceLister interface {
// List lists all TFJobs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1.TFJob, err error)
// Get retrieves the TFJob from the indexer for a given namespace and name.
Get(name string) (*v1.TFJob, error)
TFJobNamespaceListerExpansion
}
TFJobNamespaceLister helps list and get TFJobs.
type TFJobNamespaceListerExpansion ¶
type TFJobNamespaceListerExpansion interface{}
TFJobNamespaceListerExpansion allows custom methods to be added to TFJobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.